APT_TRADE_URL = "http://openapi.molit.go.kr:8081/OpenAPI_ToolInstallPackage/service/rest/RTMSOBJSvc/getRTMSDataSvcAptTrade?"
APT_TRADE_DEV_URL = "http://openapi.molit.go.kr/OpenAPI_ToolInstallPackage/service/rest/RTMSOBJSvc/getRTMSDataSvcAptTradeDev?"
COVID_INFECTION_STATUS_URL = "http://openapi.data.go.kr/openapi/service/rest/Covid19/getCovid19InfStateJson?"
NTS_BUSINESS_MAN_URL = "https://api.odcloud.kr/api/nts-businessman/v1/status?"
STATION_BY_ROUTE_URL = "http://ws.bus.go.kr/api/rest/busRouteInfo/getStaionByRoute?"
BANKING_EXCHANGE_URL = "https://www.koreaexim.go.kr/site/program/financial/exchangeJSON?"